"use client"

import { getReservations } from '@/actions/ttd';
import React from 'react'
import { toast } from 'sonner';
import BookingDetail from './booking-detail';
import { Badge } from '../ui/badge';
import moment from 'moment-timezone';
import { Button } from '../ui/button';
import { CopyIcon } from 'lucide-react';
import { copyToClipboard } from '@/lib/copy-to-clipboard';
import { ColumnDef } from '@tanstack/react-table';
import { formatCurrency } from '@/lib/format-currency';
import {
    Card,
    CardContent,
    CardDescription,
    CardHeader,
    CardTitle,
} from "@/components/ui/card"
import DataTable from '@/components/table/data-table';
import Link from 'next/link';
import { useQuery } from '@tanstack/react-query';

const ListTtd = () => {
    const [reservations, setReservations] = React.useState<any[]>([]);

    const { refetch, isPending ,isLoading} = useQuery({
        queryKey: ['home-ttd-reservations'],
        queryFn: async () => {
            const response = await getReservations(0, "");

            if (response.success) {
                const slicedData = response.data.slice(0, 5);
                setReservations(slicedData);
            }

            return response
        },
        refetchInterval: 60 * 1000 ,
        refetchOnWindowFocus: false,
    });

    const columns: ColumnDef<any>[] = [
        {
            accessorKey: 'rsvId',
            header: () => <span className='font-bold'>RSV ID</span>,
            enableSorting: true,
            enableColumnFilter: false,
            enableGlobalFilter: true,
            cell: (info: any) => {
                const row = info.row.original;
                return (
                    <div className='flex items-center'>
                        <p className='w-fit text-[13px]'>{row.rsvId}</p>
                        <Button size="sm" variant="ghost" onClick={() => copyToClipboard(row.rsvId)}>
                            <CopyIcon />
                        </Button>
                    </div>
                )
            },
        },     
        {
            accessorFn: (row: any) => row.villa.name,
            id: 'name',
            header: () => <span className='font-bold'>VILLA</span>,
            enableSorting: true,
            enableColumnFilter: false,
            enableGlobalFilter: true,
            cell: (info: any) => {
                const row = info.row.original;
                return <p className='w-fit text-[13px]'>{row.villa.name}</p>
            },
        },
        {
            accessorKey: 'paid',
            header: () => <span className='font-bold'>STATUS</span>,
            enableSorting: false,
            enableColumnFilter: false,
            enableGlobalFilter: true,
            cell: (info: any) => {
                const row = info.row.original;
                return (
                    <Badge variant={row.paid ? "green" : "red"} className='h-8'>
                        <span className='text-[13px]'>{row.paid ? "Paid" : "Pending"}</span>
                    </Badge>
                )
            },
        },
        {
            accessorFn: (row: any) => row.usd || row.idr,
            id: 'price',
            header: () => <span className='font-bold'>PRICE</span>,
            enableSorting: true,
            enableColumnFilter: false,
            enableGlobalFilter: true,
            cell: (info: any) => {
                const row = info.row.original;
                return <p className="w-fit before:content-['$'] before:mr-1 font-bold ">{formatCurrency(row.usd)}</p>
            },
        },
        {
            accessorKey: 'action',
            header: () => <span className='font-bold'>ACTION</span>,
            enableSorting: false,
            enableColumnFilter: false,
            cell: (info: any) => {
                const row = info.row.original;
                return (
                    <div className='flex items-center gap-2'>
                        <BookingDetail 
                            data={row}
                        />
                    </div>
                );
            },
        },
    ]
    return (
        <Card>
            <CardHeader>
                <CardTitle>Reservations Overview - The Tropical Door</CardTitle>
                <CardDescription>Browse and manage all current and past reservations with search and pagination.</CardDescription>
            </CardHeader>
            <CardContent className='space-y-6'>
                <div className="flex items-center justify-between gap-3">
                    <Button variant="green" onClick={() => refetch()}>
                        Refresh Data
                    </Button>
                    <Button asChild>
                        <Link href="/dashboard/ttd/reservations">
                            All Reservations
                        </Link>
                    </Button>
                </div>
                <DataTable 
                    data={reservations}
                    columns={columns}
                    isLoading={isPending || isLoading}
                    next={() => {}}
                    prev={() => {}}
                    canNextpage={true}
                    canPrevPage={true}
                    page={1}
                    allPage={1}
                    total={5}
                    placeholder={5}
                />
            </CardContent>
        </Card>
    )
}

export default ListTtd